#
# Copyright (C) 2010, audin
# 2010/11
# http://avr.paslog.jp
# This file is licensed under the MIT License.
#

# Use SCons Ver.2.0.1
# http://www.scons.org/

import os,SCons

AVR_EEP_CMD = '@$OBJCOPY -j .eeprom --set-section-flags=.eeprom="alloc,load" \
	--change-section-lma .eeprom=0 --no-change-warnings -O ihex $SOURCE $TARGET'

# output .bin/.hex/.lst files
def setup_builders( env ):
    ext = '.elf'
    #                    suffix, src_sfix,  action
    bld_dic ={  'MakeBin': [ 'bin', ext,    '@$OBJCOPY -O binary $SOURCE $TARGET']
               ,'MakeHex': [ 'hex', ext,    '@$OBJCOPY -O ihex $SOURCE $TARGET']
               ,'MakeList':[ 'lst', ext,    '@$OBJDUMP -h $SOURCE -d  > $TARGET']
               ,'MakeSize':[ None, ext,     '@$SIZE $SOURCE']
               ,'MakeEep' :[ 'eep', ext,     AVR_EEP_CMD ] 
    }
    for builder, cmd in bld_dic.iteritems():
        bld = SCons.Builder.Builder(  
                        action     = cmd[2] 
                       ,suffix     = cmd[0] 
                       ,src_suffix = cmd[1]  )
        env.Append( BUILDERS =  { builder:  bld } )

def setup_tools(env):
   ARC = { 'CORTEX-M3':' -mcpu=cortex-m3 -mthumb '
          ,'CORTEX-M0':' -mcpu=cortex-m0 -mthumb '
          ,'ARM7'     :' -mcpu=arm7tdmi-s -mthumb-interwork '
          ,'AVR'      :' '
          }
   
#   gnu_tools = ['gcc', 'g++', 'link', 'ar', 'gas']
   gnu_tools = ['mingw']
   for tool in gnu_tools:
       env.Tool(tool)
   tc                = env['TOOLCHAIN'][0]
   env['ENV']        = {'PATH' : os.environ['PATH']}
   env['CC']         = tc +'-gcc'
   env['CXX']        = tc +'-g++'
   env['AR']         = tc +'-ar'
   env['AS']         = env['CC'] 
   env['OBJCOPY']    = tc +'-objcopy'
   env['LD']         = tc + '-ld'
   env['OBJDUMP']    = tc + '-objdump'
   env['SIZE']       = tc + '-size'
   env['PROGSUFFIX'] = '.elf'
   env['CCFLAGS']    = ARC[ env['TOOLCHAIN'][1] ]
   env['LINKFLAGS']  = ARC[ env['TOOLCHAIN'][1] ]
   env['ASFLAGS']    = ARC[ env['TOOLCHAIN'][1] ] + ' -c '

def generate(env, **kwargs):
    setup_tools(env)
    setup_builders(env)
   
def exists(env):
    return -1



#########################################################################

# The MIT License
# 
# Copyright (c) 2010  audin.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
# 

